# [hmath](https://sites.google.com/view/hmath/home)

![hmath](https://lh5.googleusercontent.com/wtb0cqDGGMedHmVpQ7vavhwyIqrAzFFP5lRpc3A9fCBYsjTdJIiijO_zG1Uf1N6vmd8I87swIJTaQbtpYq8jFg=w1280)

hmath was developed to use advanced math functions in python.
You can use complex numbers for most functions.

# Version
[v.0.1.0](https://sites.google.com/view/hmath/version/v-0-1-0)

hmath is investigating whether the calculation of the function is correct and whether the calculation is efficient. 
Please help us provide information on efficient calculation methods and whether the calculations are correct.
[Click on this to answer.](https://sites.google.com/view/hmath/Feedback-on-hmath-modules)


[Feedback on hmath modules](https://sites.google.com/view/hmath/Feedback-on-hmath-modules)

